@@ -19,7 +19,7 @@ SPECIAL_CHARS = '#$€%@*&_|=+^`~<<>>'
 
 
 class TetunRegexTokenizer:
-    """Tokenizes a string (or text) using regular expressions."""
+    """Tokenizes a text using regular expressions."""
 
     def __init__(self, patterns: str, split: bool = False) -> None:
         """
@@ -42,11 +42,11 @@ class TetunRegexTokenizer:
 
 
 class TetunStandardTokenizer(TetunRegexTokenizer):
-    """ Tokenize a string (or text) by word, punctuations, and special characters delimiters. """
+    """ Tokenize a text by word, punctuations, or special characters delimiters. """
 
     def __init__(self) -> None:
         patterns = (
-            # e.g.: Área, área, ne'e, Ne'ebé, kompañia, ida-ne'e, ida-ne'ebé, etc.
+            # e.g.: Área, área, ne'e, Ne'ebé, kompañia, ida-ne'e, ida-ne'ebé.
             # e.g. person names: Ângelo, Adão, Érica, etc.
             r"[A-Za-zÂÁáãéêÉÊíÍóÓúÚñç]+(?:[-’'][A-Za-zÂÁáãéêÉÊíÍóÓúÚñç]+)*"
             r"|"
@@ -58,15 +58,23 @@ class TetunStandardTokenizer(TetunRegexTokenizer):
 
 
 class TetunWhiteSpaceTokenizer(TetunRegexTokenizer):
-    """ Tokenize text by whitespace delimiter. """
+    """ Tokenize a text by whitespace delimiter. """
 
     def __init__(self) -> None:
         patterns = r"\s+"
         super().__init__(patterns, split=True)
 
 
+class TetunSentenceTokenizer(TetunRegexTokenizer):
+    """ Tokenize a text by .?! delimiters. """
+
+    def __init__(self) -> None:
+        patterns = r"(?<!\w\.\w.)(?<![A-Z][a-z]\.)(?<=\.|\?|\!)\s"
+        super().__init__(patterns, split=True)
+
+
 class TetunBlankLineTokenizer(TetunRegexTokenizer):
-    """ Tokenize a string (or text), treating any sequence of blank lines as a delimiter. """
+    """ Tokenize a text, treating any sequence of blank lines as a delimiter. """
 
     def __init__(self) -> None:
         patterns = r"s*\n\s*\n\s*"
@@ -74,7 +82,7 @@ class TetunBlankLineTokenizer(TetunRegexTokenizer):
 
 
 class TetunSimpleTokenizer(TetunRegexTokenizer):
-    """ Tokenize a string (or text) and numbers and ignore punctuations and special characters. """
+    """ Tokenize strings and numbers and ignore punctuations and special characters. """
 
     def __init__(self) -> None:
         patterns = (
@@ -86,7 +94,7 @@ class TetunSimpleTokenizer(TetunRegexTokenizer):
 
 
 class TetunWordTokenizer(TetunRegexTokenizer):
-    """ Tokenize a string (or text) and ignore numbers, punctuations and special characters. """
+    """ Tokenize strings and ignore numbers, punctuations and special characters. """
 
     def __init__(self) -> None:
         patterns = (
